@@ -1,7 +1,8 @@
 test_that("pscrub works", {
   psx <- testthat::expect_warning(fMRIscrub:::pscrub_multi(
     Dat1,
-    projection = c("ICA", "ICA_kurt"), # "all"
+    projection = c("ICA", "ICA_kurt"),
+    ICA_method="R" # "all"
   ))
   myplot <- fMRIscrub:::plot.scrub_projection_multi(psx)
 
@@ -10,11 +11,12 @@ test_that("pscrub works", {
     projection = c("PCA", "ICA_kurt"),
     kurt_quantile = .90,
     cutoff = 5,
-    verbose = TRUE
+    verbose = TRUE,
+    ICA_method="R"
   ))
   myplot <- fMRIscrub:::plot.scrub_projection_multi(psx, title = "My Plot")
 
-  psx <- testthat::expect_warning(pscrub(Dat1))
+  psx <- testthat::expect_warning(pscrub(Dat1, ICA_method="R"))
   plot(psx)
 
   # psx <- pscrub(
@@ -24,16 +26,18 @@ test_that("pscrub works", {
   # plot(psx)
 
   psx <- testthat::expect_warning(pscrub(
-    matrix(rnorm(10000), ncol=50)
+    matrix(rnorm(10000), ncol=50), ICA_method="R"
   ))
 
   psx <- testthat::expect_warning(pscrub(
-    matrix(rnorm(10000), nrow=100) + 100, nuisance=fMRItools::dct_bases(100, 2)
+    matrix(rnorm(10000), nrow=100) + 100, nuisance=fMRItools::dct_bases(100, 2),
+    ICA_method="R"
   ))
 
   psx <- testthat::expect_warning(pscrub(
     Dat2, projection="PCA", nuisance=cbind(1, fMRItools::dct_bases(nrow(Dat2), 12)),
-    comps_mean_dt=2, comps_var_dt=2, get_dirs=TRUE, get_outliers=FALSE
+    comps_mean_dt=2, comps_var_dt=2, get_dirs=TRUE, get_outliers=FALSE,
+    ICA_method="R"
   ))
   plot(psx)
 
